/hg/gfx-test: Updated several tests.

ptisnovs at icedtea.classpath.org ptisnovs at icedtea.classpath.org
Thu Jul 16 09:00:06 UTC 2015


changeset 1e053216bad2 in /hg/gfx-test
details: http://icedtea.classpath.org/hg/gfx-test?cmd=changeset;node=1e053216bad2
author: Pavel Tisnovsky <ptisnovs at redhat.com>
date: Thu Jul 16 11:02:42 2015 +0200

	Updated several tests.


diffstat:

 ChangeLog                                          |    5 +
 src/org/gfxtest/testsuites/BitBltUsingBgColor.java |  134 ++++++++++----------
 2 files changed, 72 insertions(+), 67 deletions(-)

diffs (226 lines):

diff -r ce139fc6e574 -r 1e053216bad2 ChangeLog
--- a/ChangeLog	Wed Jul 15 12:25:10 2015 +0200
+++ b/ChangeLog	Thu Jul 16 11:02:42 2015 +0200
@@ -1,3 +1,8 @@
+2015-07-16  Pavel Tisnovsky  <ptisnovs at redhat.com>
+
+	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
+	Updated several tests.
+
 2015-07-15  Pavel Tisnovsky  <ptisnovs at redhat.com>
 
 	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
diff -r ce139fc6e574 -r 1e053216bad2 src/org/gfxtest/testsuites/BitBltUsingBgColor.java
--- a/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Wed Jul 15 12:25:10 2015 +0200
+++ b/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Thu Jul 16 11:02:42 2015 +0200
@@ -11041,7 +11041,7 @@
     }
 
     /**
      * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
      * Background color is set to Color.magenta.
      *
      * @param image
@@ -11050,13 +11050,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeIntARGB_Pre_backgroundMagenta(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeIntARGBPre(image, graphics2d, Color.magenta);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
+    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGRbackgroundMagenta(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.magenta);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
      * Background color is set to Color.yellow.
      *
      * @param image
@@ -11065,13 +11065,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeIntARGB_Pre_backgroundYellow(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeIntARGBPre(image, graphics2d, Color.yellow);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
+    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGRbackgroundYellow(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.yellow);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
      * Background color is set to Color.white.
      *
      * @param image
@@ -11080,13 +11080,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeIntARGB_Pre_backgroundWhite(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeIntARGBPre(image, graphics2d, Color.white);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
+    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGRbackgroundWhite(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.white);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_Pre}.
      * Background color is set to Color.black.
      *
      * @param image
@@ -11095,13 +11095,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryBackgroundBlack(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.black);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
+    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre_backgroundBlack(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre(image, graphics2d, Color.black);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_Pre}.
      * Background color is set to Color.blue.
      *
      * @param image
@@ -11110,13 +11110,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryBackgroundBlue(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.blue);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
+    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre_backgroundBlue(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre(image, graphics2d, Color.blue);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_Pre}.
      * Background color is set to Color.green.
      *
      * @param image
@@ -11125,13 +11125,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryBackgroundGreen(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.green);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
+    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre_backgroundGreen(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre(image, graphics2d, Color.green);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_Pre}.
      * Background color is set to Color.cyan.
      *
      * @param image
@@ -11140,13 +11140,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryBackgroundCyan(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.cyan);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
+    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre_backgroundCyan(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre(image, graphics2d, Color.cyan);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_Pre}.
      * Background color is set to Color.red.
      *
      * @param image
@@ -11155,13 +11155,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryBackgroundRed(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.red);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
+    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre_backgroundRed(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre(image, graphics2d, Color.red);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_Pre}.
      * Background color is set to Color.magenta.
      *
      * @param image
@@ -11170,13 +11170,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryBackgroundMagenta(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.magenta);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
+    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre_backgroundMagenta(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre(image, graphics2d, Color.magenta);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_Pre}.
      * Background color is set to Color.yellow.
      *
      * @param image
@@ -11185,9 +11185,9 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryBackgroundYellow(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.yellow);
+    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre_backgroundYellow(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre(image, graphics2d, Color.yellow);
     }
 
     /**
@@ -11041,7 +11041,7 @@
 
     /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
      * Background color is set to Color.magenta.
      *


More information about the distro-pkg-dev mailing list